@@ -5,6 +5,7 @@ mod use_interval;
 mod use_is_first_mount;
 mod use_is_mounted;
 mod use_latest;
+mod use_list;
 mod use_local_storage;
 mod use_mount;
 mod use_previous;
@@ -22,6 +23,7 @@ pub use use_interval::*;
 pub use use_is_first_mount::*;
 pub use use_is_mounted::*;
 pub use use_latest::*;
+pub use use_list::*;
 pub use use_local_storage::*;
 pub use use_mount::*;
 pub use use_previous::*;
