@@ -1,5 +1,8 @@
 use gloo::timers::callback::Timeout;
-use yew::{use_effect_with_deps, use_mut_ref};
+
+use yew::prelude::*;
+
+use super::use_mut_latest;
 
 /// A hook that schedules a timeout to invoke `callback` in `millis` milliseconds from now.
 /// The timeout will be cancelled if `millis` is set to 0.
@@ -33,18 +36,15 @@ pub fn use_timeout<Callback>(callback: Callback, millis: u32)
 where
     Callback: FnOnce() + 'static,
 {
-    let callback_ref = use_mut_ref(|| None);
+    let callback_ref = use_mut_latest(Some(callback));
     let timeout_ref = use_mut_ref(|| None);
 
-    // Update the ref each render so if it changes the newest callback will be invoked.
-    *callback_ref.borrow_mut() = Some(callback);
-
     use_effect_with_deps(
         move |millis| {
             if *millis > 0 {
                 *timeout_ref.borrow_mut() = Some(Timeout::new(*millis, move || {
+                    let callback_ref = callback_ref.current();
                     let callback = (*callback_ref.borrow_mut()).take();
-
                     if let Some(callback) = callback {
                         callback();
                     }
